@@ -125,7 +125,7 @@ $pconfig = array();
 if ($_SERVER['REQUEST_METHOD'] === 'GET') {
     if (isset($_GET['id']) && is_numericint($_GET['id']) && isset($a_aliases[$_GET['id']])) {
         $id = $_GET['id'];
-        foreach (array("name", "detail", "address", "type", "descr", "updatefreq", "aliasurl", "url", "proto") as $fieldname) {
+        foreach (array("name", "address", "type", "descr", "updatefreq", "aliasurl", "url", "proto") as $fieldname) {
             if (isset($a_aliases[$id][$fieldname])) {
                 $pconfig[$fieldname] = $a_aliases[$id][$fieldname];
             } else {
@@ -146,7 +146,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
             }
         }
         // initialize form fields, when not found present empty form
-        foreach (array("name", "detail", "address", "type", "descr", "updatefreq", "aliasurl", "url", "proto") as $fieldname) {
+        foreach (array("name", "address", "type", "descr", "updatefreq", "aliasurl", "url", "proto") as $fieldname) {
             if (isset($id) && isset($a_aliases[$id][$fieldname])) {
                 $pconfig[$fieldname] = $a_aliases[$id][$fieldname];
             } else {
@@ -155,7 +155,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
         }
     } else {
         // init empty
-        $init_fields = array("name", "detail", "address", "type", "descr", "updatefreq", "url", "proto");
+        $init_fields = array("name", "address", "type", "descr", "updatefreq", "url", "proto");
         foreach ($init_fields as $fieldname) {
             $pconfig[$fieldname] = null;
         }
@@ -170,7 +170,6 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
     } else {
         $pconfig['host_url'] = array();
     }
-    $pconfig['detail'] = !empty($pconfig['detail']) ? explode("||", $pconfig['detail']) : array();
     $pconfig['proto'] = !empty($pconfig['proto']) ? explode(',', $pconfig['proto']) : array("IPv4");
 } elseif ($_SERVER['REQUEST_METHOD'] === 'POST') {
     $pconfig = $_POST;
@@ -178,15 +177,6 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
         $id = $_POST['id'];
     }
 
-    foreach ($pconfig['detail'] as &$detailDescr) {
-        if (empty($detailDescr)) {
-            $detailDescr = sprintf(gettext("Entry added %s"), date('r'));
-        } else {
-            // trim and strip pipes
-            $detailDescr = trim(str_replace('|',' ' , $detailDescr));
-        }
-    }
-
     if (isset($pconfig['submit'])) {
         $input_errors = array();
         // validate data
@@ -312,8 +302,6 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
             } else {
                 $confItem['address'] = implode(' ', $pconfig['host_url']);
             }
-            //
-            $confItem['detail'] = implode('||', $pconfig['detail']);
 
             // proto is only for geoip selection
             if ($pconfig['type'] == 'geoip') {
@@ -352,6 +340,8 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
 
             // save to config
             if (isset($id)) {
+                // temporary keep data in detail field, will be removed post 18.7
+                $confItem['detail'] = !empty($a_aliases[$id]['detail']) ? $a_aliases[$id]['detail'] : null;
                 $a_aliases[$id] = $confItem;
             } else {
                 $a_aliases[] = $confItem;
@@ -438,13 +428,6 @@ include("head.inc");
         $("#addNew").addClass('hidden');
         $('#detailTable > tbody > tr:gt(0)').remove();
         $('.act-removerow').addClass('hidden');
-      } else if ($("#typeSelect").val() == 'urltable_ports') {
-        $("#updatefreq").addClass('hidden');
-        $("#updatefreq_hours").addClass('hidden');
-        $("#updatefreqHeader").addClass('hidden');
-        $("#addNew").addClass('hidden');
-        $('#detailTable > tbody > tr:gt(0)').remove();
-        $('.act-removerow').addClass('hidden');
       } else {
         $("#updatefreq").addClass('hidden');
         $("#updatefreq_hours").addClass('hidden');
@@ -462,15 +445,9 @@ include("head.inc");
           case 'urltable':
               $("#detailsHeading1").html("<?=gettext("URL");?>");
               break;
-          case 'urltable_ports':
-              $("#detailsHeading1").html("<?=gettext("URL");?>");
-              break;
           case 'url':
               $("#detailsHeading1").html("<?=gettext("URL");?>");
               break;
-          case 'url_ports':
-              $("#detailsHeading1").html("<?=gettext("URL");?>");
-              break;
           case 'host':
               $("#detailsHeading1").html("<?=gettext("Host(s)");?>");
               break;
@@ -574,9 +551,7 @@ include("head.inc");
                       <option value="network" <?=$pconfig['type'] == "network" ? "selected=\"selected\"" : ""; ?>><?=gettext("Network(s)"); ?></option>
                       <option value="port" <?=$pconfig['type'] == "port" ? "selected=\"selected\"" : ""; ?>><?=gettext("Port(s)"); ?></option>
                       <option value="url" <?=$pconfig['type'] == "url" ? "selected=\"selected\"" : ""; ?>><?=gettext("URL (IPs)");?></option>
-                      <option value="url_ports" <?=$pconfig['type'] == "url_ports" ? "selected=\"selected\"" : ""; ?>><?=gettext("URL (Ports)");?></option>
                       <option value="urltable" <?=$pconfig['type'] == "urltable" ? "selected=\"selected\"" : ""; ?>><?=gettext("URL Table (IPs)"); ?></option>
-                      <option value="urltable_ports" <?=$pconfig['type'] == "urltable_ports" ? "selected=\"selected\"" : ""; ?>><?=gettext("URL Table (Ports)"); ?></option>
                       <option value="geoip" <?=$pconfig['type'] == "geoip" ? "selected=\"selected\"" : ""; ?>><?=gettext("GeoIP"); ?></option>
                       <option value="external" <?=$pconfig['type'] == "external" ? "selected=\"selected\"" : ""; ?>><?=gettext("External (advanced)"); ?></option>
                     </select>
@@ -641,7 +616,6 @@ include("head.inc");
                         <tr>
                           <th></th>
                           <th id="detailsHeading1"><?=gettext("Network"); ?></th>
-                          <th id="detailsHeading3"><?=gettext("Description"); ?></th>
                           <th colspan="2" id="updatefreqHeader" ><?=gettext("Alias Expiration. (days + hours)");?></th>
                         </tr>
                       </thead>
@@ -650,15 +624,12 @@ include("head.inc");
                       foreach (!empty($pconfig['host_url']) ? $pconfig['host_url'] : array("") as $aliasid => $aliasurl):?>
                         <tr>
                           <td>
-                            <div style="cursor:pointer;" class="act-removerow btn btn-default btn-xs" alt="remove"><span class="glyphicon glyphicon-minus"></span></div>
+                            <div style="cursor:pointer;" class="act-removerow btn btn-default btn-xs" alt="remove"><i class="fa fa-minus fa-fw"></i></div>
                           </td>
                           <td>
                             <input type="text" class="host_url fld_detail" name="host_url[]" value="<?=$aliasurl;?>"/>
                           </td>
                           <td>
-                            <input type="text" class="form-control" name="detail[]" value="<?= isset($pconfig['detail'][$aliasid])?$pconfig['detail'][$aliasid]:"";?>">
-                          </td>
-                          <td>
 <?php
                             if ($aliasid == 0):?>
                             <input type="text" class="form-control input-sm" id="updatefreq"  name="updatefreq" value="<?=$pconfig['updatefreq'];?>" >
@@ -679,7 +650,7 @@ include("head.inc");
                       <tfoot>
                         <tr>
                           <td colspan="4">
-                            <div id="addNew" style="cursor:pointer;" class="btn btn-default btn-xs" alt="add"><span class="glyphicon glyphicon-plus"></span></div>
+                            <div id="addNew" style="cursor:pointer;" class="btn btn-default btn-xs" alt="add"><i class="fa fa-plus fa-fw"></i></div>
                           </td>
                         </tr>
                       </tfoot>
