@@ -35,6 +35,22 @@ require_once("services.inc");
 require_once("filter.inc");
 require_once("interfaces.inc");
 
+
+/* expand a host or network alias, if necessary */
+function alias_expand($name)
+{
+    global $aliastable;
+
+    if (array_key_exists($name, $aliastable)) {
+        return "\${$name}";
+    } elseif (is_ipaddr($name) || is_subnet($name) || is_port($name) || is_portrange($name)) {
+        return "{$name}";
+    } else {
+        return null;
+    }
+}
+
+
 function filter_generate_port(& $rule, $target = "source", $isnat = false) {
     $src = "";
 
@@ -701,11 +717,18 @@ function openvpn_client_export_sharedkey_config($srvid, $useaddr, $proxy, $zipco
         $conf .= openvpn_gen_routes($settings['local_networkv6'], 'ipv6');
     }
     if (!empty($settings['tunnel_network'])) {
-        list($ip, $mask) = explode('/', $settings['tunnel_network']);
-        $mask = gen_subnet_mask($mask);
+        list($ip, $prefix_length) = explode('/', $settings['tunnel_network']);
+        $mask = gen_subnet_mask($prefix_length);
         $baselong = ip2long32($ip) & ip2long($mask);
-        $ip1 = long2ip32($baselong + 1);
-        $ip2 = long2ip32($baselong + 2);
+
+        if ($prefix_length == "31") {
+            // As per RFC3021, in a /31 network, first address is the first host address
+            $ip1 = long2ip32($baselong);
+            $ip2 = long2ip32($baselong + 1);
+        } else {
+            $ip1 = long2ip32($baselong + 1);
+            $ip2 = long2ip32($baselong + 2);
+        }
         $conf .= "ifconfig $ip2 $ip1\n";
     }
     $conf .= "keepalive 10 60\n";
@@ -1278,7 +1301,7 @@ if (isset($savemsg)) {
                 </td>
               </tr>
               <tr>
-                <td style="vertical-align:top"><i class="fa fa-info-circle text-muted"></i> <?=gettext("Remote Access Server");?></td>
+                <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("Remote Access Server");?></td>
                 <td>
                   <select name="server" id="server">
 <?php
@@ -1290,7 +1313,7 @@ if (isset($savemsg)) {
                 </td>
               </tr>
               <tr>
-                <td style="vertical-align:top"><i class="fa fa-info-circle text-muted"></i> <?=gettext("Host Name Resolution");?></td>
+                <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("Host Name Resolution");?></td>
                 <td>
                       <select name="useaddr" id="useaddr">
                         <option value="serveraddr" ><?=gettext("Interface IP Address");?></option>
@@ -1326,7 +1349,7 @@ if (isset($savemsg)) {
                 </td>
               </tr>
               <tr class="mode_server">
-                <td style="vertical-align:top"><a id="help_for_verify_server_cn" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Verify Server CN");?></td>
+                <td><a id="help_for_verify_server_cn" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Verify Server CN");?></td>
                 <td>
                       <select name="verifyservercn" id="verifyservercn">
                         <option value="auto"><?=gettext("Automatic - Use verify-x509-name (OpenVPN 2.3+) where possible");?></option>
@@ -1342,7 +1365,7 @@ if (isset($savemsg)) {
                 </td>
               </tr>
               <tr class="mode_server">
-                <td style="vertical-align:top"><a id="help_for_random_local_port" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Use Random Local Port");?></td>
+                <td><a id="help_for_random_local_port" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Use Random Local Port");?></td>
                 <td>
                       <input name="randomlocalport" id="randomlocalport" type="checkbox" value="yes" checked="CHECKED" />
                       <div class="hidden" data-for="help_for_random_local_port">
@@ -1352,7 +1375,7 @@ if (isset($savemsg)) {
                       </div>
               </tr>
               <tr class="mode_server">
-                <td style="vertical-align:top"><i class="fa fa-info-circle text-muted"></i> <?=gettext("Certificate Export Options");?></td>
+                <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("Certificate Export Options");?></td>
                 <td>
                       <div>
                         <input name="usetoken" id="usetoken" type="checkbox" value="yes" />
@@ -1371,7 +1394,7 @@ if (isset($savemsg)) {
                 </td>
               </tr>
               <tr>
-                <td style="vertical-align:top"><a id="help_for_http_proxy" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Use Proxy");?></td>
+                <td><a id="help_for_http_proxy" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Use Proxy");?></td>
                 <td>
                       <input name="useproxy" id="useproxy" type="checkbox" value="yes" />
                       <div class="hidden" data-for="help_for_http_proxy">
@@ -1407,7 +1430,7 @@ if (isset($savemsg)) {
                 </td>
               </tr>
               <tr class="mode_server">
-                <td style="vertical-align:top"><a id="help_for_openvpnmanager" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Management Interface OpenVPN Manager");?></td>
+                <td><a id="help_for_openvpnmanager" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Management Interface OpenVPN Manager");?></td>
                 <td>
                       <input name="openvpnmanager" id="openvpnmanager" type="checkbox" value="yes" />
                       <div class="hidden" data-for="help_for_openvpnmanager">
@@ -1418,13 +1441,13 @@ if (isset($savemsg)) {
                 </td>
               </tr>
               <tr class="mode_server">
-                <td style="vertical-align:top"><a id="help_for_advancedoptions" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Additional configuration options");?></td>
+                <td><a id="help_for_advancedoptions" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext("Additional configuration options");?></td>
                 <td>
-                      <textarea rows="6" cols="68" name="advancedoptions" id="advancedoptions"></textarea><br/>
-                      <div class="hidden" data-for="help_for_advancedoptions">
-                        <?=gettext("Enter any additional options you would like to add to the OpenVPN client export configuration here, separated by a line break or semicolon"); ?><br/>
-                        <?=gettext("EXAMPLE: remote-random"); ?>;
-                      </div>
+                  <textarea rows="6" cols="68" name="advancedoptions" id="advancedoptions"></textarea>
+                  <div class="hidden" data-for="help_for_advancedoptions">
+                    <?=gettext("Enter any additional options you would like to add to the OpenVPN client export configuration here, separated by a line break or semicolon"); ?><br/>
+                    <?=gettext("EXAMPLE: remote-random"); ?>;
+                  </div>
                 </td>
               </tr>
               <tr>
@@ -1561,7 +1584,7 @@ if (isset($savemsg)) {
                   </td>
                 </tr>
                 <tr>
-                  <td style="vertical-align:top"><i class="fa fa-info-circle text-muted"></i> <?=gettext("Links to OpenVPN clients");?></td>
+                  <td><i class="fa fa-info-circle text-muted"></i> <?=gettext("Links to OpenVPN clients");?></td>
                   <td>
                     <a href="http://www.sparklabs.com/viscosity/" target="_blank"><?= gettext("Viscosity") ?></a> - <?= gettext("Recommended client for Mac OSX and Windows") ?><br/>
                     <a href="http://openvpn.net/index.php/open-source/downloads.html" target="_blank"><?= gettext("OpenVPN Community Client") ?></a> - <?=gettext("Binaries for Windows, Source for other platforms.")?><br/>
